==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ToolPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.ad("ToolPanelContentRefreshedEventArgs", () => new ToolPanelContentRefreshedEventArgsDescription());
            a.ac("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ToolPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.ae("ToolPanelContentRefreshedEventArgs", () => new ToolPanelContentRefreshedEventArgsDescription());
            a.ad("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
})();
